==> plantuml-libs-5.2.0.tgz: package/distribution/aws-20210730/Resource/Storage/AwsStorageGatewayVolumeGateway.md <==
# AwsStorageGatewayVolumeGateway


```text
aws-20210730/Resource/Storage/AwsStorageGatewayVolumeGateway
```

```text
include('aws-20210730/Resource/Storage/AwsStorageGatewayVolumeGateway')
```



| Illustration | AwsStorageGatewayVolumeGateway | AwsStorageGatewayVolumeGatewayCard | AwsStorageGatewayVolumeGatewayGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/Storage/AwsStorageGatewayVolumeGateway.png) | ![illustration for AwsStorageGatewayVolumeGateway](../../../aws-20210730/Resource/Storage/AwsStorageGatewayVolumeGateway.Local.png) | ![illustration for AwsStorageGatewayVolumeGatewayCard](../../../aws-20210730/Resource/Storage/AwsStorageGatewayVolumeGatewayCard.Local.png) | ![illustration for AwsStorageGatewayVolumeGatewayGroup](../../../aws-20210730/Resource/Storage/AwsStorageGatewayVolumeGatewayGroup.Local.png) |




## AwsStorageGatewayVolumeGateway

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsStorageGatewayVolumeGateway
include('aws-20210730/Resource/Storage/AwsStorageGatewayVolumeGateway')

' renders the element
AwsStorageGatewayVolumeGateway('AwsStorageGatewayVolumeGateway', 'Aws Storage Gateway Volume Gateway', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsStorageGatewayVolumeGateway
include('aws-20210730/Resource/Storage/AwsStorageGatewayVolumeGateway')

' renders the element
AwsStorageGatewayVolumeGateway('AwsStorageGatewayVolumeGateway', 'Aws Storage Gateway Volume Gateway', 'an optional tech label')
@enduml
```

## AwsStorageGatewayVolumeGatewayCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsStorageGatewayVolumeGatewayCard
include('aws-20210730/Resource/Storage/AwsStorageGatewayVolumeGateway')

' renders the element
AwsStorageGatewayVolumeGatewayCard('AwsStorageGatewayVolumeGatewayCard', 'Aws Storage Gateway Volume Gateway Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsStorageGatewayVolumeGatewayCard
include('aws-20210730/Resource/Storage/AwsStorageGatewayVolumeGateway')

' renders the element
AwsStorageGatewayVolumeGatewayCard('AwsStorageGatewayVolumeGatewayCard', 'Aws Storage Gateway Volume Gateway Card', 'an optional description')
@enduml
```

## AwsStorageGatewayVolumeGatewayGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsStorageGatewayVolumeGatewayGroup
include('aws-20210730/Resource/Storage/AwsStorageGatewayVolumeGateway')

' renders the element
AwsStorageGatewayVolumeGatewayGroup('AwsStorageGatewayVolumeGatewayGroup', 'Aws Storage Gateway Volume Gateway Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsStorageGatewayVolumeGatewayGroup
include('aws-20210730/Resource/Storage/AwsStorageGatewayVolumeGateway')

' renders the element
AwsStorageGatewayVolumeGatewayGroup('AwsStorageGatewayVolumeGatewayGroup', 'Aws Storage Gateway Volume Gateway Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.3.0.tgz: package/distribution/aws-20210730/Resource/Storage/AwsStorageGatewayVolumeGateway.md <==
# AwsStorageGatewayVolumeGateway


```text
aws-20210730/Resource/Storage/AwsStorageGatewayVolumeGateway
```

```text
include('aws-20210730/Resource/Storage/AwsStorageGatewayVolumeGateway')
```



| Illustration | AwsStorageGatewayVolumeGateway | AwsStorageGatewayVolumeGatewayCard | AwsStorageGatewayVolumeGatewayGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/Storage/AwsStorageGatewayVolumeGateway.png) | ![illustration for AwsStorageGatewayVolumeGateway](../../../aws-20210730/Resource/Storage/AwsStorageGatewayVolumeGateway.Local.png) | ![illustration for AwsStorageGatewayVolumeGatewayCard](../../../aws-20210730/Resource/Storage/AwsStorageGatewayVolumeGatewayCard.Local.png) | ![illustration for AwsStorageGatewayVolumeGatewayGroup](../../../aws-20210730/Resource/Storage/AwsStorageGatewayVolumeGatewayGroup.Local.png) |




## AwsStorageGatewayVolumeGateway

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsStorageGatewayVolumeGateway
include('aws-20210730/Resource/Storage/AwsStorageGatewayVolumeGateway')

' renders the element
AwsStorageGatewayVolumeGateway('AwsStorageGatewayVolumeGateway', 'Aws Storage Gateway Volume Gateway', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsStorageGatewayVolumeGateway
include('aws-20210730/Resource/Storage/AwsStorageGatewayVolumeGateway')

' renders the element
AwsStorageGatewayVolumeGateway('AwsStorageGatewayVolumeGateway', 'Aws Storage Gateway Volume Gateway', 'an optional tech label')
@enduml
```

## AwsStorageGatewayVolumeGatewayCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsStorageGatewayVolumeGatewayCard
include('aws-20210730/Resource/Storage/AwsStorageGatewayVolumeGateway')

' renders the element
AwsStorageGatewayVolumeGatewayCard('AwsStorageGatewayVolumeGatewayCard', 'Aws Storage Gateway Volume Gateway Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsStorageGatewayVolumeGatewayCard
include('aws-20210730/Resource/Storage/AwsStorageGatewayVolumeGateway')

' renders the element
AwsStorageGatewayVolumeGatewayCard('AwsStorageGatewayVolumeGatewayCard', 'Aws Storage Gateway Volume Gateway Card', 'an optional description')
@enduml
```

## AwsStorageGatewayVolumeGatewayGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsStorageGatewayVolumeGatewayGroup
include('aws-20210730/Resource/Storage/AwsStorageGatewayVolumeGateway')

' renders the element
AwsStorageGatewayVolumeGatewayGroup('AwsStorageGatewayVolumeGatewayGroup', 'Aws Storage Gateway Volume Gateway Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsStorageGatewayVolumeGatewayGroup
include('aws-20210730/Resource/Storage/AwsStorageGatewayVolumeGateway')

' renders the element
AwsStorageGatewayVolumeGatewayGroup('AwsStorageGatewayVolumeGatewayGroup', 'Aws Storage Gateway Volume Gateway Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
